==> consensusDE_1.0.1.tar.gz: consensusDE/inst/doc/consensusDE.R <==
## ----setup, include = FALSE----------------------------------------------
# setting of some global variables
knitr::opts_chunk$set(
  collapse = TRUE,
  #comment = "#>",
  library(consensusDE),
  library(airway),
  data(airway),
  colData(airway)$group <- colData(airway)$dex,
  colData(airway)$file <- rownames(colData(airway)),
  airway_filter <- buildSummarized(summarized = airway,
                                   filter = TRUE),
  set.seed(1234),
  airway_filter <- sample(airway_filter, 5000),
  all_pairs_airway <- multi_de_pairs(summarized = airway_filter,
                                     ruv_correct = FALSE,
                                     paired = "unpaired"),
  comparison <- all_pairs_airway$merged[["untrt-trt"]],
  comparison_list <- list("untrt-trt" = comparison),
  colnames(comparison_list[["untrt-trt"]]) <- gsub("edger_adj_p", "Adj_PVal",
                                      colnames(comparison_list[["untrt-trt"]]))

)

## ----eval=FALSE----------------------------------------------------------
#  # load consensusDE
#  library(consensusDE)
#  
#  # load airway and dm3 transcript database for example annotation
#  library(airway)
#  library(TxDb.Dmelanogaster.UCSC.dm3.ensGene)
#  
#  data("airway")

## ----eval=FALSE----------------------------------------------------------
#  # build a design table that lists the files and their grouping
#  file_list <- list.files(system.file("extdata", package="GenomicAlignments"),
#                          recursive = TRUE,
#                          pattern = "*bam$",
#                          full = TRUE)
#  
#  # Prepare a sample table to be used with buildSummarized()
#  # must be comprised of a minimum of two columns, named "file" and "group", with one additional column: "pairing" if the data is paired
#  sample_table <- data.frame("file" = basename(file_list),
#                             "group" = c("treat", "untreat"))
#  
#  # extract the path to the bam directory - where to search for files listed in "sample_table"
#  bam_dir <- as.character(gsub(basename(file_list)[1], "", file_list[1]))
#  

## ----eval=FALSE----------------------------------------------------------
#  summarized_dm3 <- buildSummarized(sample_table = sample_table,
#                                    bam_dir = bam_dir,
#                                    tx_db = TxDb.Dmelanogaster.UCSC.dm3.ensGene,
#                                    read_format = "paired")

## ----eval=FALSE----------------------------------------------------------
#  summarized_dm3
#  
#  # class: RangedSummarizedExperiment
#  # dim: 15682 2
#  # metadata(0):
#  # assays(1): counts
#  # rownames(15682): FBgn0000003 FBgn0000008 ... FBgn0264726 FBgn0264727
#  # rowData names(0):
#  # colnames(2): sm_treated1.bam sm_untreated1.bam
#  # colData names(2): file group

## ----eval=FALSE----------------------------------------------------------
#  # for compatability, add "group" and "file" columns
#  colData(airway)$group <- colData(airway)$dex
#  colData(airway)$file <- rownames(colData(airway))
#  
#  # filter low count data
#  airway_filter <- buildSummarized(summarized = airway,
#                                   filter = TRUE)
#  
#  # for illustration, we only use sa random sample of 1000 transcripts
#  set.seed(1234)
#  airway_filter <- sample(airway_filter, 1000)
#  
#  # call multi_de_pairs()
#  all_pairs_airway <- multi_de_pairs(summarized = airway_filter,
#                                     paired = "unpaired",
#                                     ruv_correct = FALSE)
#  

## ----eval=FALSE----------------------------------------------------------
#  # To view all the comparisons conducted:
#  names(all_pairs_airway$merged)
#  # [1] "untrt-trt"
#  
#  # to access data of a particular comparison
#  head(all_pairs_airway$merged[["untrt-trt"]])
#  
#  #                ID   AveExpr     LogFC  edger_adj_p   deseq_adj_p   voom_adj_p edger_rank deseq_rank voom_rank rank_sum
#  # 1 ENSG00000152583  7.848478 -4.579048 4.555352e-81 1.689976e-105 2.434237e-05          1          1         1        2
#  # 2 ENSG00000196517  6.707906  2.238648 7.174030e-29  2.375309e-40 7.700210e-05          2          2         2        4
#  # 3 ENSG00000123562 11.471330 -1.008375 9.124547e-14  8.201734e-31 3.724219e-04          6          3         3        9
#  # 4 ENSG00000250978  2.929392 -6.159170 3.441794e-28  1.985784e-18 7.780662e-04          3          6         5        9
#  # 5 ENSG00000103485  8.891566  1.231192 1.586426e-14  6.843112e-19 5.406701e-04          5          5         4       10
#  # 6 ENSG00000169738  8.158014 -2.128064 1.381426e-15  7.176291e-18 1.424488e-03          4          8        12       12

## ----eval=FALSE----------------------------------------------------------
#  
#  # call multi_de_pairs()
#  all_pairs_airway_ruv <- multi_de_pairs(summarized = airway_filter,
#                                         paired = "unpaired",
#                                         ruv_correct = TRUE)
#  
#  # access the summarized experiment (now including the residuals under the "W_1" column)
#  colData(all_pairs_airway_ruv$summarized)
#  
#  # DataFrame with 8 rows and 3 columns
#  #                  file    group                 W_1
#  #              <factor> <factor>           <numeric>
#  # SRR1039508 SRR1039508    untrt  -0.142570931413377
#  # SRR1039509 SRR1039509      trt  -0.178946892813184
#  # SRR1039512 SRR1039512    untrt -0.0505852352323729
#  # SRR1039513 SRR1039513      trt  -0.199848364864245
#  # SRR1039516 SRR1039516    untrt   0.472530975797452
#  # SRR1039517 SRR1039517      trt   0.703116609741865
#  # SRR1039520 SRR1039520    untrt   -0.25051443379887
#  # SRR1039521 SRR1039521      trt  -0.353181727417269

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(se_in = airway_filter,
           name = "airway example data",
           mapped_reads = TRUE)

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(se_in = airway_filter,
           name = "airway example data",
           rle = TRUE)

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(se_in = airway_filter,
           name = "airway example data",
           pca = TRUE)

## ----eval=FALSE----------------------------------------------------------
#  diag_plots(se_in = all_pairs_airway$summarized,
#             name = "airway example data",
#             residuals = TRUE)

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(se_in = airway_filter,
           name = "airway example data",
           hclust = TRUE)

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(se_in = airway_filter,
           name = "airway example data",
           density = TRUE)

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(se_in = airway_filter,
           name = "airway example data",
           boxplot = TRUE)

## ----eval=FALSE----------------------------------------------------------
#  # 1. View all the comparisons conducted
#  names(all_pairs_airway$merged)
#  [1] "untrt-trt"
#  
#  # 2. Extract the data.frame of interest of a particular comparison
#  comparison <- all_pairs_airway$merged[["untrt-trt"]]
#  
#  # this will not work unless in a list and will stop, producing an error. E.g.
#  diag_plots(merged_in = comparison,
#             name = "untrt-trt",
#             ma = TRUE)
#  
#  # Error message:
#  merged_in is not a list. If you want to plot with one comparison only,
#  put the single dataframe into a list as follows. my_list <- list("name"=
#  merged_in)
#  
#  # 3. Put into a new list as instructed by the error
#  comparison_list <- list("untrt-trt" = comparison)
#  
#  # this will not work unless the appropriate columns are labelled
#  # "ID", "AveExpr", and "Adj_PVal"
#  
#  diag_plots(merged_in = comparison_list,
#             name = "untrt-trt",
#             ma = TRUE)
#  # Error message:
#  merged_in contains 1 slots that are not
#  "data.frame" objects with column names containing "ID", "AveExpr", and
#  "Adj_PVal".
#  
#  # 3. Relabel the columns for plotting
#  # inspecting the column names reveals that the "Adj_PVal" column needs to be specified.
#  colnames(comparison_list[["untrt-trt"]])
#  
#  # replace "edger_adj_p" with "Adj_PVal" to use this p-value, using the "gsub" command as follows
#  colnames(comparison_list[["untrt-trt"]]) <- gsub("edger_adj_p", "Adj_PVal",
#                                                   colnames(comparison_list[["untrt-trt"]]))
#  

## ----echo=TRUE, message=FALSE--------------------------------------------
# 4. Plot MA
diag_plots(merged_in = comparison_list,
           name = "untrt-trt",
           ma = TRUE)

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(merged_in = comparison_list,
           name = "untrt-trt",
           volcano = TRUE)

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(merged_in = comparison_list,
           name = "untrt-trt",
           p_dist = TRUE)

## ----echo=TRUE, message=FALSE, warning=FALSE-----------------------------
citation("consensusDE")

==> consensusDE_1.0.5.tar.gz: consensusDE/inst/doc/consensusDE.R <==
## ----setup, include = FALSE----------------------------------------------
# setting of some global variables
knitr::opts_chunk$set(
  collapse = TRUE,
  #comment = "#>",
  library(consensusDE),
  library(airway),
  data(airway),
  colData(airway)$group <- colData(airway)$dex,
  colData(airway)$file <- rownames(colData(airway)),
  airway_filter <- buildSummarized(summarized = airway,
                                   filter = TRUE),
  set.seed(1234),
  airway_filter <- sample(airway_filter, 5000),
  all_pairs_airway <- multi_de_pairs(summarized = airway_filter,
                                     ruv_correct = FALSE,
                                     paired = "unpaired"),
  comparison <- all_pairs_airway$merged[["untrt-trt"]],
  comparison_list <- list("untrt-trt" = comparison),
  colnames(comparison_list[["untrt-trt"]]) <- gsub("edger_adj_p", "Adj_PVal",
                                      colnames(comparison_list[["untrt-trt"]]))

)

## ----eval=FALSE----------------------------------------------------------
#  # load consensusDE
#  library(consensusDE)
#  
#  # load airway and dm3 transcript database for example annotation
#  library(airway)
#  library(TxDb.Dmelanogaster.UCSC.dm3.ensGene)
#  
#  data("airway")

## ----eval=FALSE----------------------------------------------------------
#  # build a design table that lists the files and their grouping
#  file_list <- list.files(system.file("extdata", package="GenomicAlignments"),
#                          recursive = TRUE,
#                          pattern = "*bam$",
#                          full = TRUE)
#  
#  # Prepare a sample table to be used with buildSummarized()
#  # must be comprised of a minimum of two columns, named "file" and "group",
#  # with one additional column: "pairs" if the data is paired
#  
#  sample_table <- data.frame("file" = basename(file_list),
#                             "group" = c("treat", "untreat"))
#  
#  # extract the path to the bam directory - where to search for files listed in "sample_table"
#  bam_dir <- as.character(gsub(basename(file_list)[1], "", file_list[1]))
#  

## ----eval=FALSE----------------------------------------------------------
#  # NB. force_build = TRUE, is set to allow the Summarized Experiment to be built.
#  # This will report a Warning message that less than two replicates are present
#  # in the sample_table.
#  
#  summarized_dm3 <- buildSummarized(sample_table = sample_table,
#                                    bam_dir = bam_dir,
#                                    tx_db = TxDb.Dmelanogaster.UCSC.dm3.ensGene,
#                                    read_format = "paired",
#                                    force_build = TRUE)

## ----eval=FALSE----------------------------------------------------------
#  summarized_dm3
#  
#  # class: RangedSummarizedExperiment
#  # dim: 15682 2
#  # metadata(0):
#  # assays(1): counts
#  # rownames(15682): FBgn0000003 FBgn0000008 ... FBgn0264726 FBgn0264727
#  # rowData names(0):
#  # colnames(2): sm_treated1.bam sm_untreated1.bam
#  # colData names(2): file group

## ----eval=FALSE----------------------------------------------------------
#  # for compatability, add "group" and "file" columns
#  colData(airway)$group <- colData(airway)$dex
#  colData(airway)$file <- rownames(colData(airway))
#  
#  # filter low count data
#  airway_filter <- buildSummarized(summarized = airway,
#                                   filter = TRUE)
#  
#  # for illustration, we only use sa random sample of 1000 transcripts
#  set.seed(1234)
#  airway_filter <- sample(airway_filter, 1000)
#  
#  # call multi_de_pairs()
#  all_pairs_airway <- multi_de_pairs(summarized = airway_filter,
#                                     paired = "unpaired",
#                                     ruv_correct = FALSE)
#  

## ----eval=FALSE----------------------------------------------------------
#  # To view all the comparisons conducted:
#  names(all_pairs_airway$merged)
#  # [1] "untrt-trt"
#  
#  # to access data of a particular comparison
#  head(all_pairs_airway$merged[["untrt-trt"]])
#  
#  #                ID   AveExpr     LogFC  edger_adj_p   deseq_adj_p   voom_adj_p edger_rank deseq_rank voom_rank rank_sum
#  # 1 ENSG00000152583  7.848478 -4.579048 4.555352e-81 1.689976e-105 2.434237e-05          1          1         1        2
#  # 2 ENSG00000196517  6.707906  2.238648 7.174030e-29  2.375309e-40 7.700210e-05          2          2         2        4
#  # 3 ENSG00000123562 11.471330 -1.008375 9.124547e-14  8.201734e-31 3.724219e-04          6          3         3        9
#  # 4 ENSG00000250978  2.929392 -6.159170 3.441794e-28  1.985784e-18 7.780662e-04          3          6         5        9
#  # 5 ENSG00000103485  8.891566  1.231192 1.586426e-14  6.843112e-19 5.406701e-04          5          5         4       10
#  # 6 ENSG00000169738  8.158014 -2.128064 1.381426e-15  7.176291e-18 1.424488e-03          4          8        12       12

## ----eval=FALSE----------------------------------------------------------
#  # first ensure annotation database in installed
#  # load annotation library:
#  library(org.Hs.eg.db)
#  
#  # call multi_de_pairs(),
#  # set ensembl_annotate argument to org.Hs.eg.db
#  all_pairs_airway <- multi_de_pairs(summarized = airway_filter,
#                                     paired = "unpaired",
#                                     ruv_correct = FALSE,
#                                     ensembl_annotate = org.Hs.eg.db)
#  

## ----eval=FALSE----------------------------------------------------------
#  
#  # call multi_de_pairs()
#  all_pairs_airway_ruv <- multi_de_pairs(summarized = airway_filter,
#                                         paired = "unpaired",
#                                         ruv_correct = TRUE)
#  
#  # access the summarized experiment (now including the residuals under the "W_1" column)
#  colData(all_pairs_airway_ruv$summarized)
#  
#  # DataFrame with 8 rows and 3 columns
#  #                  file    group                 W_1
#  #              <factor> <factor>           <numeric>
#  # SRR1039508 SRR1039508    untrt  -0.142570931413377
#  # SRR1039509 SRR1039509      trt  -0.178946892813184
#  # SRR1039512 SRR1039512    untrt -0.0505852352323729
#  # SRR1039513 SRR1039513      trt  -0.199848364864245
#  # SRR1039516 SRR1039516    untrt   0.472530975797452
#  # SRR1039517 SRR1039517      trt   0.703116609741865
#  # SRR1039520 SRR1039520    untrt   -0.25051443379887
#  # SRR1039521 SRR1039521      trt  -0.353181727417269

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(se_in = airway_filter,
           name = "airway example data",
           mapped_reads = TRUE)

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(se_in = airway_filter,
           name = "airway example data",
           rle = TRUE)

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(se_in = airway_filter,
           name = "airway example data",
           pca = TRUE)

## ----eval=FALSE----------------------------------------------------------
#  diag_plots(se_in = all_pairs_airway$summarized,
#             name = "airway example data",
#             residuals = TRUE)

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(se_in = airway_filter,
           name = "airway example data",
           hclust = TRUE)

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(se_in = airway_filter,
           name = "airway example data",
           density = TRUE)

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(se_in = airway_filter,
           name = "airway example data",
           boxplot = TRUE)

## ----eval=FALSE----------------------------------------------------------
#  # 1. View all the comparisons conducted
#  names(all_pairs_airway$merged)
#  [1] "untrt-trt"
#  
#  # 2. Extract the data.frame of interest of a particular comparison
#  comparison <- all_pairs_airway$merged[["untrt-trt"]]
#  
#  # this will not work unless in a list and will stop, producing an error. E.g.
#  diag_plots(merged_in = comparison,
#             name = "untrt-trt",
#             ma = TRUE)
#  
#  # Error message:
#  merged_in is not a list. If you want to plot with one comparison only,
#  put the single dataframe into a list as follows. my_list <- list("name"=
#  merged_in)
#  
#  # 3. Put into a new list as instructed by the error
#  comparison_list <- list("untrt-trt" = comparison)
#  
#  # this will not work unless the appropriate columns are labelled
#  # "ID", "AveExpr", and "Adj_PVal"
#  
#  diag_plots(merged_in = comparison_list,
#             name = "untrt-trt",
#             ma = TRUE)
#  # Error message:
#  merged_in contains 1 slots that are not
#  "data.frame" objects with column names containing "ID", "AveExpr", and
#  "Adj_PVal".
#  
#  # 3. Relabel the columns for plotting
#  # inspecting the column names reveals that the "Adj_PVal" column needs to be specified.
#  colnames(comparison_list[["untrt-trt"]])
#  
#  # replace "edger_adj_p" with "Adj_PVal" to use this p-value, using the "gsub" command as follows
#  colnames(comparison_list[["untrt-trt"]]) <- gsub("edger_adj_p", "Adj_PVal",
#                                                   colnames(comparison_list[["untrt-trt"]]))
#  

## ----echo=TRUE, message=FALSE--------------------------------------------
# 4. Plot MA
diag_plots(merged_in = comparison_list,
           name = "untrt-trt",
           ma = TRUE)

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(merged_in = comparison_list,
           name = "untrt-trt",
           volcano = TRUE)

## ----echo=TRUE, message=FALSE--------------------------------------------
diag_plots(merged_in = comparison_list,
           name = "untrt-trt",
           p_dist = TRUE)

## ----echo=TRUE, message=FALSE, warning=FALSE-----------------------------
citation("consensusDE")
